@@ -1,7 +1,7 @@
 package Bencher;
 
 our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -948,6 +948,7 @@ sub format_result {
 
     # remove constant item permutation columns to reduce clutter
     {
+        last unless @{$envres->[2]};
         require TableData::Object::aohos;
         my $td = TableData::Object::aohos->new($envres->[2]);
         my @const_cols = $td->const_col_names;
@@ -959,6 +960,17 @@ sub format_result {
         }
     }
 
+    # remove notes column if there are none
+  REMOVE_NOTES:
+    {
+        for my $row (@{$envres->[2]}) {
+            last REMOVE_NOTES if $row->{notes};
+        }
+        for my $row (@{$envres->[2]}) {
+            delete $row->{notes};
+        }
+    }
+
     $envres;
 }
 
@@ -1817,7 +1829,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.28 of Bencher (from Perl distribution Bencher), released on 2016-01-11.
+This document describes version 0.29 of Bencher (from Perl distribution Bencher), released on 2016-01-11.
 
 =head1 SYNOPSIS
 
